==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Line/LineRelativeAngle/ts/LineRelativeAngle_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>LineRelativeAngle</name>
    <message>
        <source>Choose base entity</source>
        <translation type="vanished">基礎エントリーを選択</translation>
    </message>
    <message>
        <location filename="../LineRelativeAngle.js" line="+70"/>
        <source>Choose base line, arc, circle, ellipse or polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Set position</source>
        <translation>位置を指定</translation>
    </message>
    <message>
        <location filename="../LineRelativeAngle.ui" line="+17"/>
        <source>Relative Angle:</source>
        <translation>相対角度:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Length:</source>
        <translation>長さ:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Reference Point:</source>
        <translation>&amp;R 基準点:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Middle</source>
        <translation>中央</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>End</source>
        <translation>終端</translation>
    </message>
    <message>
        <location filename="../LineRelativeAngleInit.js" line="+2"/>
        <source>R&amp;elative Angle</source>
        <translation>&amp;e 相対角度</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw line with relative angle to base entity</source>
        <translation>基礎エントリーとの相対角度で線分を描画</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Line/LineRelativeAngle/ts/LineRelativeAngle_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>LineRelativeAngle</name>
    <message>
        <source>Choose base entity</source>
        <translation type="vanished">基礎エントリーを選択</translation>
    </message>
    <message>
        <location filename="../LineRelativeAngle.js" line="+70"/>
        <source>Choose base line, arc, circle, ellipse or polyline</source>
        <translation>ベースの線分、弧、円、楕円またはポリラインを選択してください</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Set position</source>
        <translation>位置を指定</translation>
    </message>
    <message>
        <location filename="../LineRelativeAngle.ui" line="+17"/>
        <source>Relative Angle:</source>
        <translation>相対角度:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Length:</source>
        <translation>長さ:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Reference Point:</source>
        <translation>&amp;R 基準点:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Middle</source>
        <translation>中央</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>End</source>
        <translation>終端</translation>
    </message>
    <message>
        <location filename="../LineRelativeAngleInit.js" line="+2"/>
        <source>R&amp;elative Angle</source>
        <translation>&amp;e 相対角度</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw line with relative angle to base entity</source>
        <translation>基礎エントリーとの相対角度で線分を描画</translation>
    </message>
</context>
</TS>
